==> mysql-5.7_5.7.33.orig.tar.gz: mysql-5.7.33/include/my_rnd.h <==
#ifndef MY_RANDOM_INCLUDED
#define MY_RANDOM_INCLUDED

/*
   Copyright (c) 2012, 2019, Oracle and/or its affiliates. All rights reserved.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is also distributed with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have included with MySQL.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/*
  A wrapper to use OpenSSL PRNGs.
*/

#include <my_global.h>
#include <mysql_com.h>

#ifdef __cplusplus
extern "C" {
#endif

double my_rnd_ssl(struct rand_struct *rand_st);
int my_rand_buffer(unsigned char *buffer, size_t buffer_size);

#ifdef __cplusplus
}
#endif

#endif /* MY_RANDOM_INCLUDED */

==> mysql-8.4.8.tar.gz: mysql-8.4.8/include/my_rnd.h <==
#ifndef MY_RANDOM_INCLUDED
#define MY_RANDOM_INCLUDED

/*
   Copyright (c) 2012, 2025, Oracle and/or its affiliates.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License, version 2.0,
   as published by the Free Software Foundation.

   This program is designed to work with certain software (including
   but not limited to OpenSSL) that is licensed under separate terms,
   as designated in a particular file or component or in included license
   documentation.  The authors of MySQL hereby grant you an additional
   permission to link the program and your derivative works with the
   separately licensed software that they have either included with
   the program or referenced in the documentation.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License, version 2.0, for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA */

/**
  @file include/my_rnd.h
  A wrapper to use OpenSSL PRNGs.
*/

#include <stddef.h>

double my_rnd_ssl(bool *failed);
int my_rand_buffer(unsigned char *buffer, size_t buffer_size);
void randominit(struct rand_struct *, unsigned long seed1, unsigned long seed2);
double my_rnd(struct rand_struct *);

#endif /* MY_RANDOM_INCLUDED */
